@@ -6,5 +6,6 @@
 
 from text2vec.version import __version__
 from text2vec.word2vec import Word2Vec
-from text2vec.sbert import SBert
+from text2vec.sbert import SBert, semantic_search, cos_sim
 from text2vec.bm25 import BM25
+from text2vec.similarity import Similarity, SearchSimilarity, SimType, EmbType
